@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-python
-# Copyright(C) 2018 Fridolin Pokorny
+# Copyright(C) 2018, 2019 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -55,49 +55,43 @@ class PipfileMeta:
         _LOGGER.debug("Parsing Pipfile/Pipfile.lock metadata section")
         dict_ = dict(dict_)
 
-        if 'sources' in dict_:
+        if "sources" in dict_:
             # Naming is confusing here - Pipfile uses source, Pipfile.lock sources.
-            dict_['source'] = dict_.pop('sources')
+            dict_["source"] = dict_.pop("sources")
 
-        if 'source' not in dict_:
-            dict_['source'] = []
+        if "source" not in dict_:
+            dict_["source"] = []
 
-        sources = {d['name']: Source.from_dict(d) for d in dict_.pop('source')}
-        requires = dict_.pop('requires', None)
-        pipenv = dict_.pop('pipenv', None)
-        pipfile_spec = dict_.pop('pipfile-spec', None)
-        hash_ = dict_.pop('hash', None)
+        sources = {d["name"]: Source.from_dict(d) for d in dict_.pop("source")}
+        requires = dict_.pop("requires", {})
+        pipenv = dict_.pop("pipenv", None)
+        pipfile_spec = dict_.pop("pipfile-spec", None)
+        hash_ = dict_.pop("hash", None)
 
         if dict_:
             _LOGGER.warning("Metadata ignored in Pipfile or Pipfile.lock: %s", dict_)
 
-        return cls(
-            sources=sources,
-            requires=requires,
-            pipenv=pipenv,
-            hash=hash_,
-            pipfile_spec=pipfile_spec
-        )
+        return cls(sources=sources, requires=requires, pipenv=pipenv, hash=hash_, pipfile_spec=pipfile_spec)
 
     def to_dict(self, is_lock: bool = False):
         """Produce sources as a dict representation as stated in Pipfile/Pipfile.lock."""
-        _LOGGER.debug("Generating Pipfile%s metadata section", '' if not is_lock else '.lock')
+        _LOGGER.debug("Generating Pipfile%s metadata section", "" if not is_lock else ".lock")
         sources_dict = [source.to_dict() for source in self.sources.values()]
 
         result = {}
         if is_lock:
             # Pipenv is omitted.
-            result['sources'] = sources_dict
-            result['requires'] = self.requires or {}
-            result['hash'] = self.hash
-            result['pipfile-spec'] = self.pipfile_spec or _DEFAULT_PIPFILE_SPEC
+            result["sources"] = sources_dict
+            result["requires"] = self.requires or {}
+            result["hash"] = self.hash
+            result["pipfile-spec"] = self.pipfile_spec or _DEFAULT_PIPFILE_SPEC
         else:
-            result['source'] = sources_dict
+            result["source"] = sources_dict
             if self.pipenv:
-                result['pipenv'] = self.pipenv
+                result["pipenv"] = self.pipenv
 
             if self.requires:
-                result['requires'] = self.requires
+                result["requires"] = self.requires
 
         return result
 
@@ -107,15 +101,15 @@ class PipfileMeta:
 
     def to_requirements_index_conf(self) -> str:
         """Add index configuration as would be stated in the requirements.txt file."""
-        result = ''
+        result = ""
 
         primary_index_added = False
         for source in self.sources.items():
             if not primary_index_added:
-                result += f'-i {source.url}\n'
+                result += f"-i {source.url}\n"
                 primary_index_added = True
             else:
-                result += f'--extra-index-url {source.url}\n'
+                result += f"--extra-index-url {source.url}\n"
 
         return result
 
@@ -179,7 +173,7 @@ class _PipfileBase:
         requirements_file = self.meta.to_requirements_index_conf()
 
         for package_version in self.packages.items() if not develop else self.dev_packages.items():
-            requirements_file += f'{package_version.name}{package_version.version}'
+            requirements_file += f"{package_version.name}{package_version.version}"
 
         return requirements_file
 
@@ -193,6 +187,7 @@ class _PipfileBase:
     def sanitize_source_indexes(self):
         """Make sure all indexes used by packages are registerd in meta."""
         _LOGGER.debug("Checking source indexes used")
+
         def _index_check(package_version: PackageVersion, source: Source):
             if source is package_version.index:
                 return
@@ -205,7 +200,7 @@ class _PipfileBase:
                 )
             elif source.name == package_version.index.name and source.verify_ssl != package_version.index.verify_ssl:
                 raise InternalError(
-                    f"Found package source index {source} with different SSL verifycation settings "
+                    f"Found package source index {source} with different SSL verification settings "
                     f"but same URL as for package {package_version.name} in "
                     f"version {package_version.version}: {package_version.index}"
                 )
@@ -231,12 +226,8 @@ class Pipfile(_PipfileBase):
         """Return data used to compute hash based on Pipfile stored in Pipfile.lock."""
         meta = self.meta.to_dict(is_lock=True)
         # Only these values are used to compute digest.
-        meta = {'requires': meta['requires'], 'sources': meta['sources']}
-        return {
-            'default': self.packages.to_pipfile(),
-            'develop': self.dev_packages.to_pipfile(),
-            '_meta': meta
-        }
+        meta = {"requires": meta["requires"], "sources": meta["sources"]}
+        return {"default": self.packages.to_pipfile(), "develop": self.dev_packages.to_pipfile(), "_meta": meta}
 
     @classmethod
     def from_package_versions(cls, packages: typing.List[PackageVersion], meta: PipfileMeta = None):
@@ -244,15 +235,15 @@ class Pipfile(_PipfileBase):
         return cls(
             packages=Packages.from_package_versions([pv for pv in packages if not pv.develop], develop=False),
             dev_packages=Packages.from_package_versions([pv for pv in packages if pv.develop], develop=True),
-            meta=meta or PipfileMeta.from_dict({})
+            meta=meta or PipfileMeta.from_dict({}),
         )
 
     @classmethod
     def from_file(cls, file_path: str = None):
         """Parse Pipfile file and return its Pipfile representation."""
-        file_path = file_path or 'Pipfile'
+        file_path = file_path or "Pipfile"
         _LOGGER.debug("Loading Pipfile from %r", file_path)
-        with open(file_path, 'r') as pipfile_file:
+        with open(file_path, "r") as pipfile_file:
             return cls.from_string(pipfile_file.read())
 
     @classmethod
@@ -275,24 +266,21 @@ class Pipfile(_PipfileBase):
     def from_dict(cls, dict_):
         """Retrieve instance of Pipfile from its dictionary representation."""
         _LOGGER.debug("Parsing Pipfile")
-        packages = dict_.pop('packages', {})
-        dev_packages = dict_.pop('dev-packages', {})
+        packages = dict_.pop("packages", {})
+        dev_packages = dict_.pop("dev-packages", {})
 
         # Use remaining parts - such as requires, pipenv configuration and other flags.
         meta = PipfileMeta.from_dict(dict_)
         return cls(
             packages=Packages.from_pipfile(packages, develop=False, meta=meta),
             dev_packages=Packages.from_pipfile(dev_packages, develop=True, meta=meta),
-            meta=meta
+            meta=meta,
         )
 
     def to_dict(self) -> dict:
         """Return Pipfile representation as dict."""
         _LOGGER.debug("Generating Pipfile")
-        result = {
-            'packages': self.packages.to_pipfile(),
-            'dev-packages': self.dev_packages.to_pipfile()
-        }
+        result = {"packages": self.packages.to_pipfile(), "dev-packages": self.dev_packages.to_pipfile()}
         result.update(self.meta.to_dict())
         return result
 
@@ -303,7 +291,7 @@ class Pipfile(_PipfileBase):
 
     def to_file(self) -> None:
         """Convert the current state of Pipfile to actual Pipfile file stored in CWD."""
-        with open('Pipfile', 'w') as pipfile:
+        with open("Pipfile", "w") as pipfile:
             pipfile.write(self.to_string())
 
     def hash(self):
@@ -312,7 +300,7 @@ class Pipfile(_PipfileBase):
         content = json.dumps(self.data, sort_keys=True, separators=(",", ":"))
         hexdigest = hashlib.sha256(content.encode("utf8")).hexdigest()
         _LOGGER.debug("Computed hash for %r: %r", content, hexdigest)
-        return {'sha256': hexdigest}
+        return {"sha256": hexdigest}
 
 
 @attr.s(slots=True)
@@ -322,22 +310,21 @@ class PipfileLock(_PipfileBase):
     pipfile = attr.ib(type=Pipfile)
 
     @classmethod
-    def from_package_versions(cls, pipfile: Pipfile, packages: typing.List[PackageVersion],
-                              meta: PipfileMeta = None):
+    def from_package_versions(cls, pipfile: Pipfile, packages: typing.List[PackageVersion], meta: PipfileMeta = None):
         """Construct Pipfile from provided PackageVersion instances."""
         return cls(
             pipfile=pipfile,
             packages=Packages.from_package_versions([pv for pv in packages if not pv.develop], develop=False),
             dev_packages=Packages.from_package_versions([pv for pv in packages if pv.develop], develop=True),
-            meta=meta
+            meta=meta,
         )
 
     @classmethod
     def from_file(cls, file_path: str = None, pipfile: Pipfile = None):
         """Parse Pipfile.lock file and return its PipfileLock representation."""
-        file_path = file_path or 'Pipfile.lock'
+        file_path = file_path or "Pipfile.lock"
         _LOGGER.debug("Loading Pipfile.lock from %r", file_path)
-        with open(file_path, 'r') as pipfile_file:
+        with open(file_path, "r") as pipfile_file:
             return cls.from_string(pipfile_file.read(), pipfile)
 
     @classmethod
@@ -355,22 +342,22 @@ class PipfileLock(_PipfileBase):
     def from_dict(cls, dict_: dict, pipfile: Pipfile):
         """Construct PipfileLock class from a parsed JSON representation as stated in actual Pipfile.lock."""
         _LOGGER.debug("Parsing Pipfile.lock")
-        meta = PipfileMeta.from_dict(dict_['_meta'])
+        meta = PipfileMeta.from_dict(dict_["_meta"])
         return cls(
             meta=meta,
-            packages=Packages.from_pipfile_lock(dict_['default'], develop=False, meta=meta),
-            dev_packages=Packages.from_pipfile_lock(dict_['develop'], develop=True, meta=meta),
-            pipfile=pipfile
+            packages=Packages.from_pipfile_lock(dict_["default"], develop=False, meta=meta),
+            dev_packages=Packages.from_pipfile_lock(dict_["develop"], develop=True, meta=meta),
+            pipfile=pipfile,
         )
 
     def to_string(self, pipfile: Pipfile = None) -> str:
         """Convert the current state of PipfileLock to its Pipfile.lock file representation."""
         _LOGGER.debug("Converting Pipfile.lock to JSON")
-        return json.dumps(self.to_dict(pipfile), sort_keys=True, indent=4) + '\n'
+        return json.dumps(self.to_dict(pipfile), sort_keys=True, indent=4) + "\n"
 
     def to_file(self, pipfile: Pipfile = None) -> None:
         """Convert the current state of PipfileLock to actual Pipfile.lock file stored in CWD."""
-        with open('Pipfile.lock', 'w') as pipfile_lock:
+        with open("Pipfile.lock", "w") as pipfile_lock:
             pipfile_lock.write(self.to_string(pipfile))
 
     def to_dict(self, pipfile: Pipfile = None) -> dict:
@@ -385,8 +372,8 @@ class PipfileLock(_PipfileBase):
         self.sanitize_source_indexes()
 
         content = {
-            '_meta': self.meta.to_dict(is_lock=True),
-            'default': self.packages.to_pipfile_lock(),
-            'develop': self.dev_packages.to_pipfile_lock()
+            "_meta": self.meta.to_dict(is_lock=True),
+            "default": self.packages.to_pipfile_lock(),
+            "develop": self.dev_packages.to_pipfile_lock(),
         }
         return content
